==> valknut-0.4.0a.tar.bz2: valknut-0.4.0a/valknut/dctransferview.h <==
/***************************************************************************
                          dctransferview.h  -  description
                             -------------------
    begin                : Sat Feb 23 2002
    copyright            : (C) 2002-2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCTRANSFERVIEW_H
#define DCTRANSFERVIEW_H

/**
  *@author Mathias Kster
  */

#include <QVector>
//Added by qt3to4:
#include <QResizeEvent>
#include <QEvent>
#include <QCloseEvent>
#include <QList>

#include <dclib/dcobject.h>
#include <dclib/cdownloadmanager.h>

#include "dcwidget.h"

#include "DCDialogTransfer.h"

class CObject;
class Q3ListViewItem;

typedef QVector<QString> QStringVector;

/** */
class DCTransferQueueItem : public CObject {
public:
	/** construtor */
	DCTransferQueueItem() {
		pObject = 0;
		pItem   = 0;
	};
	/** destructor */
	virtual ~DCTransferQueueItem() {};

	/** */
	CString sHubName;
	/** */
	CString sHubHost;

	/** */
	CObject * pObject;
	/** */
	Q3ListViewItem * pItem;
};

/** */
class DCTransferListItem : public CObject {
public:
	/** construtor */
	DCTransferListItem() {
		pObject = 0;
		pItem   = 0;
	};
	/** destructor */
	virtual ~DCTransferListItem() {};

	/** */
	CObject * pObject;
	/** */
	DC_QProgressListItem * pItem;
};

class DCFileBrowser;
class QMdiArea;
class QTimer;
class QTextEdit;

class DCTransferView : public QWidget, private Ui::DCDialogTransfer, public CDownloadManager {
Q_OBJECT

public:
	/** construtor */
	DCTransferView(QWidget* parent, const char *name, Qt::WindowFlags wflags);
	/** destructor */
	virtual ~DCTransferView();

	/** */
	void SetMdiArea(QMdiArea* mdiarea);
	/** */
	void InitDocument();
	/** */
	void DeInitDocument();
	/** */
	void NewLocalFileBrowser( bool lock );
	/** */
	void NewFileBrowser( QString nick, QString hubname, QString hubhost, QString share );
	/** */
	bool IsUserInQueue( QString Nick, QString Hubname );
	/** returns the list of the local files names in the queue list. The path is included.*/
	void GetLocalFilesList( QStringVector & LocalFiles, ulonglong size = 0);
	/** download manager callback function */
	virtual int DC_DownloadManagerCallBack( CObject * );
	/** overridden so that the columns are resized on show() */
	virtual void show();

protected:
	/** resize the ListView columns */
	void ResizeListViewColumn();

	/** event filter */
	virtual bool eventFilter( QObject * object, QEvent * event );
	/** close event handler */
	virtual void closeEvent( QCloseEvent * ) {};
	/** resize event handler */
	virtual void resizeEvent( QResizeEvent * );

private:
	/** */
	void MessageSlot( CMessageDMSlotObject * msg );
	/** */
	void MessageLog( CMessageLog * msg );
	/** */
	void MessageTransfer( CMessageDMTransferObject * msg );

	/** */
	void ConnectToAllHubs();
	/** */
	void SearchFileClone(QString filename, ulonglong size);
        /** */
	int selectedItems(Q3ListView * list, QList<Q3ListViewItem*> & lst);
	/** */
	ulonglong FindTransferID( Q3ListViewItem * item );
	/** */
	eConnectionState GetTransferDirection( ulonglong sid );
	/** */
	bool GetTransferMessageObject( Q3ListViewItem * item, CMessageDMTransferObject * obj );

	/** */
	bool UpdateTransferWaitList( CMessageDMFileObject * msg );
	/** */
	bool UpdateLocalFileList( CMessageDMFileObject * msg );
	/** */
	void EditExistingTransfer( QString & nick, QString & hubname, QString & hubhost, CList<DCHubObject> * list );
	/** */
	CList<CObject> * pMessageList;
	/** */
	CThreadStringList * pViewTransferList;
	/** */
	CThread * Thread;
	/** */
	QMdiArea * pMdiArea;
	/** */
	CList<DCFileBrowser> * pFileList;
	/** */
	QTimer * Timer;
	/** */
	CThreadStringList * pQueueList;
	/** */
	CThreadStringList * pQueueLocalList;
	/** */
	QTextEdit * m_pTextEdit_LOG;

private slots:
	/** */
	void timerDone();
	/** */
	void slotRightButtonClickedTransferList( Q3ListViewItem*, const QPoint &, int );
	/** */
	void slotRightButtonClickedTransferWaitList( Q3ListViewItem*, const QPoint &, int );
	/** */
	void slotRightButtonClickedLocalFilesList( Q3ListViewItem*, const QPoint &, int );
	/** */
	void slotTabWidgetCurrentChange(QWidget*);
	/** */
	void slotDoubleClickedTransferWaitList( Q3ListViewItem* );
	/** */
	void slotContextMenuUserSlotList( const QPoint & );
	/** */
	void slotRightButtonClickedLog( const QPoint& );
};

/** */
extern DCTransferView * g_pTransferView;

#endif

==> valknut-0.4.3.tar.bz2: valknut-0.4.3/valknut/dctransferview.h <==
/***************************************************************************
                          dctransferview.h  -  description
                             -------------------
    begin                : Sat Feb 23 2002
    copyright            : (C) 2002-2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCTRANSFERVIEW_H
#define DCTRANSFERVIEW_H

/**
  *@author Mathias Kster
  */

#include <QVector>
//Added by qt3to4:
#include <QResizeEvent>
#include <QEvent>
#include <QCloseEvent>
#include <QList>

#include <dclib/dcobject.h>
#include <dclib/cdownloadmanager.h>

#include "dcwidget.h"

#include "DCDialogTransfer.h"

class CObject;
class Q3ListViewItem;

typedef QVector<QString> QStringVector;

/** */
class DCTransferQueueItem : public CObject {
public:
	/** construtor */
	DCTransferQueueItem() {
		pObject = 0;
		pItem   = 0;
	};
	/** destructor */
	virtual ~DCTransferQueueItem() {
		if ( pObject != 0 )
		{
			delete pObject;
			pObject = 0;
		}
	};

	/** */
	CString sHubName;
	/** */
	CString sHubHost;

	/** */
	CObject * pObject;
	/** */
	Q3ListViewItem * pItem;
};

/** */
class DCTransferListItem : public CObject {
public:
	/** construtor */
	DCTransferListItem() {
		pObject = 0;
		pItem   = 0;
	};
	/** destructor */
	virtual ~DCTransferListItem() {
		if ( pObject != 0 )
		{
			delete pObject;
			pObject = 0;
		}
	};

	/** */
	CObject * pObject;
	/** */
	DC_QProgressListItem * pItem;
};

class DCFileBrowser;
class QMdiArea;
class QTimer;
class QTextEdit;

class DCTransferView : public QWidget, private Ui::DCDialogTransfer, public CDownloadManager {
Q_OBJECT

public:
	/** construtor */
	DCTransferView(QWidget* parent, const char *name, Qt::WindowFlags wflags);
	/** destructor */
	virtual ~DCTransferView();

	/** */
	void SetMdiArea(QMdiArea* mdiarea);
	/** */
	void InitDocument();
	/** */
	void DeInitDocument();
	/** */
	void NewLocalFileBrowser( bool lock );
	/** */
	void NewFileBrowser( QString nick, QString hubname, QString hubhost, QString share );
	/** */
	bool IsUserInQueue( QString Nick, QString Hubname );
	/** returns the list of the local files names in the queue list. The path is included.*/
	void GetLocalFilesList( QStringVector & LocalFiles, ulonglong size = 0);
	/** returns the list of the local files names in the queue list that match the TTH */
	void GetLocalFilesList( QStringVector & LocalFiles, QString tth );
	/** download manager callback function */
	virtual int DC_DownloadManagerCallBack( CObject * );
	/** overridden so that the columns are resized on show() */
	virtual void show();

protected:
	/** resize the ListView columns */
	void ResizeListViewColumn();

	/** event filter */
	virtual bool eventFilter( QObject * object, QEvent * event );
	/** close event handler */
	virtual void closeEvent( QCloseEvent * ) {};
	/** resize event handler */
	virtual void resizeEvent( QResizeEvent * );

private:
	/** */
	void MessageSlot( CMessageDMSlotObject * msg );
	/** */
	void MessageLog( CMessageLog * msg );
	/** */
	void MessageTransfer( CMessageDMTransferObject * msg );

	/** */
	void ConnectToAllHubs();
	/** */
	void SearchFileClone(QString filename, ulonglong size);
        /** */
	int selectedItems(Q3ListView * list, QList<Q3ListViewItem*> & lst);
	/** */
	ulonglong FindTransferID( Q3ListViewItem * item );
	/** */
	eConnectionState GetTransferDirection( ulonglong sid );
	/** */
	bool GetTransferMessageObject( Q3ListViewItem * item, CMessageDMTransferObject * obj );

	/** */
	bool UpdateTransferWaitList( CMessageDMFileObject * msg );
	/** */
	bool UpdateLocalFileList( CMessageDMFileObject * msg );
	/** */
	void EditExistingTransfer( QString & nick, QString & hubname, QString & hubhost, CList<DCHubObject> * list );
	/** */
	CList<CObject> * pMessageList;
	/** */
	CThreadStringList * pViewTransferList;
	/** */
	CThread * Thread;
	/** */
	QMdiArea * pMdiArea;
	/** */
	CList<DCFileBrowser> * pFileList;
	/** */
	QTimer * Timer;
	/** */
	CThreadStringList * pQueueList;
	/** */
	CThreadStringList * pQueueLocalList;
	/** */
	QTextEdit * m_pTextEdit_LOG;

private slots:
	/** */
	void timerDone();
	/** */
	void slotRightButtonClickedTransferList( Q3ListViewItem*, const QPoint &, int );
	/** */
	void slotRightButtonClickedTransferWaitList( Q3ListViewItem*, const QPoint &, int );
	/** */
	void slotRightButtonClickedLocalFilesList( Q3ListViewItem*, const QPoint &, int );
	/** */
	void slotTabWidgetCurrentChange(QWidget*);
	/** */
	void slotDoubleClickedTransferWaitList( Q3ListViewItem* );
	/** */
	void slotContextMenuUserSlotList( const QPoint & );
	/** */
	void slotRightButtonClickedLog( const QPoint& );
};

/** */
extern DCTransferView * g_pTransferView;

#endif
